@@ -2,9 +2,10 @@ from functools import partial
 from typing import Optional, Callable, List, Any
 
 import pytorch_lightning as pl
+
 from torch.utils.data import DataLoader
 
-from quaterion.dataset import (
+from quaterion.dataset.similarity_data_loader import (
     PairsSimilarityDataLoader,
     GroupSimilarityDataLoader,
 )
@@ -53,13 +54,15 @@ class Quaterion:
                 )
             elif isinstance(trainable_model.loss, PairwiseLoss):
                 raise NotImplementedError(
-                    "Pair samplers are not implemented yet. Try other loss/data loader"
+                    "Pair samplers are not implemented yet. "
+                    "Try other loss/data loader"
                 )
 
         if val_dataloader is not None:
             val_dataloader.collate_fn = train_dataloader.collate_fn
 
         trainable_model.cache(
+            trainer,
             trainable_model.model.encoders,
             train_dataloader,
             val_dataloader,
